@@ -1,10 +1,8 @@
 func.predValue <-
-function(data.fit, data, pos, writeOutputTarget ){
+function(data.fit, data, pos ){
   if(names(data.fit$coefficients)[1] == "(Intercept)"){
     pred = data.fit$coefficients[1]
 
-    #writeLines(pred, con = writeOutputTarget )
-
     for(i in 2:NROW(data.fit$coefficients)){
       pred = pred + data.fit$coefficients[i] * data[pos, i - 1]
     }
